"""
The MIT License (MIT)

Copyright (c) 2016 Gehad Shaat

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


def can_paginate(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            ReturnsTrue if the operation can be paginated,
            False otherwise.
            
    :type operation_name: string
    """
    pass

def cancel_export_task(taskId=None):
    """
    :param taskId: [REQUIRED]
            Id of the export task to cancel.
            ReturnsNone
            
    :type taskId: string
    """
    pass

def create_export_task(taskName=None, logGroupName=None, logStreamNamePrefix=None, fromTime=None, to=None, destination=None, destinationPrefix=None):
    """
    :param taskName: The name of the export task.
    :type taskName: string
    :param logGroupName: [REQUIRED]
            The name of the log group to export.
            
    :type logGroupName: string
    :param logStreamNamePrefix: Will only export log streams that match the provided logStreamNamePrefix. If you don't specify a value, no prefix filter is applied.
    :type logStreamNamePrefix: string
    :param fromTime: [REQUIRED]
            A point in time expressed as the number of milliseconds since Jan 1, 1970 00:00:00 UTC. It indicates the start time of the range for the request. Events with a timestamp prior to this time will not be exported.
            
    :type fromTime: integer
    :param to: [REQUIRED]
            A point in time expressed as the number of milliseconds since Jan 1, 1970 00:00:00 UTC. It indicates the end time of the range for the request. Events with a timestamp later than this time will not be exported.
            
    :type to: integer
    :param destination: [REQUIRED]
            Name of Amazon S3 bucket to which the log data will be exported.
            Note: Only buckets in the same AWS region are supported.
            
    :type destination: string
    :param destinationPrefix: Prefix that will be used as the start of Amazon S3 key for every object exported. If not specified, this defaults to 'exportedlogs'.
    :type destinationPrefix: string
    """
    pass

def create_log_group(logGroupName=None):
    """
    :param logGroupName: [REQUIRED]
            The name of the log group to create.
            ReturnsNone
            
    :type logGroupName: string
    """
    pass

def create_log_stream(logGroupName=None, logStreamName=None):
    """
    :param logGroupName: [REQUIRED]
            The name of the log group under which the log stream is to be created.
            
    :type logGroupName: string
    :param logStreamName: [REQUIRED]
            The name of the log stream to create.
            
    :type logStreamName: string
    """
    pass

def delete_destination(destinationName=None):
    """
    :param destinationName: [REQUIRED]
            The name of destination to delete.
            ReturnsNone
            
    :type destinationName: string
    """
    pass

def delete_log_group(logGroupName=None):
    """
    :param logGroupName: [REQUIRED]
            The name of the log group to delete.
            ReturnsNone
            
    :type logGroupName: string
    """
    pass

def delete_log_stream(logGroupName=None, logStreamName=None):
    """
    :param logGroupName: [REQUIRED]
            The name of the log group under which the log stream to delete belongs.
            
    :type logGroupName: string
    :param logStreamName: [REQUIRED]
            The name of the log stream to delete.
            
    :type logStreamName: string
    """
    pass

def delete_metric_filter(logGroupName=None, filterName=None):
    """
    :param logGroupName: [REQUIRED]
            The name of the log group that is associated with the metric filter to delete.
            
    :type logGroupName: string
    :param filterName: [REQUIRED]
            The name of the metric filter to delete.
            
    :type filterName: string
    """
    pass

def delete_retention_policy(logGroupName=None):
    """
    :param logGroupName: [REQUIRED]
            The name of the log group that is associated with the retention policy to delete.
            ReturnsNone
            
    :type logGroupName: string
    """
    pass

def delete_subscription_filter(logGroupName=None, filterName=None):
    """
    :param logGroupName: [REQUIRED]
            The name of the log group that is associated with the subscription filter to delete.
            
    :type logGroupName: string
    :param filterName: [REQUIRED]
            The name of the subscription filter to delete.
            
    :type filterName: string
    """
    pass

def describe_destinations(DestinationNamePrefix=None, nextToken=None, limit=None):
    """
    :param DestinationNamePrefix: Will only return destinations that match the provided destinationNamePrefix. If you don't specify a value, no prefix is applied.
    :type DestinationNamePrefix: string
    :param nextToken: A string token used for pagination that points to the next page of results. It must be a value obtained from the response of the previous request. The token expires after 24 hours.
    :type nextToken: string
    :param limit: The maximum number of results to return.
    :type limit: integer
    """
    pass

def describe_export_tasks(taskId=None, statusCode=None, nextToken=None, limit=None):
    """
    :param taskId: Export task that matches the specified task Id will be returned. This can result in zero or one export task.
    :type taskId: string
    :param statusCode: All export tasks that matches the specified status code will be returned. This can return zero or more export tasks.
    :type statusCode: string
    :param nextToken: A string token used for pagination that points to the next page of results. It must be a value obtained from the response of the previous DescribeExportTasks request.
    :type nextToken: string
    :param limit: The maximum number of items returned in the response. If you don't specify a value, the request would return up to 50 items.
    :type limit: integer
    """
    pass

def describe_log_groups(logGroupNamePrefix=None, nextToken=None, limit=None):
    """
    :param logGroupNamePrefix: Will only return log groups that match the provided logGroupNamePrefix. If you don't specify a value, no prefix filter is applied.
    :type logGroupNamePrefix: string
    :param nextToken: A string token used for pagination that points to the next page of results. It must be a value obtained from the response of the previous DescribeLogGroups request.
    :type nextToken: string
    :param limit: The maximum number of items returned in the response. If you don't specify a value, the request would return up to 50 items.
    :type limit: integer
    """
    pass

def describe_log_streams(logGroupName=None, logStreamNamePrefix=None, orderBy=None, descending=None, nextToken=None, limit=None):
    """
    :param logGroupName: [REQUIRED]
            The log group name for which log streams are to be listed.
            
    :type logGroupName: string
    :param logStreamNamePrefix: Will only return log streams that match the provided logStreamNamePrefix. If you don't specify a value, no prefix filter is applied.
    :type logStreamNamePrefix: string
    :param orderBy: Specifies what to order the returned log streams by. Valid arguments are 'LogStreamName' or 'LastEventTime'. If you don't specify a value, results are ordered by LogStreamName. If 'LastEventTime' is chosen, the request cannot also contain a logStreamNamePrefix.
    :type orderBy: string
    :param descending: If set to true, results are returned in descending order. If you don't specify a value or set it to false, results are returned in ascending order.
    :type descending: boolean
    :param nextToken: A string token used for pagination that points to the next page of results. It must be a value obtained from the response of the previous DescribeLogStreams request.
    :type nextToken: string
    :param limit: The maximum number of items returned in the response. If you don't specify a value, the request would return up to 50 items.
    :type limit: integer
    """
    pass

def describe_metric_filters(logGroupName=None, filterNamePrefix=None, nextToken=None, limit=None):
    """
    :param logGroupName: [REQUIRED]
            The log group name for which metric filters are to be listed.
            
    :type logGroupName: string
    :param filterNamePrefix: Will only return metric filters that match the provided filterNamePrefix. If you don't specify a value, no prefix filter is applied.
    :type filterNamePrefix: string
    :param nextToken: A string token used for pagination that points to the next page of results. It must be a value obtained from the response of the previous DescribeMetricFilters request.
    :type nextToken: string
    :param limit: The maximum number of items returned in the response. If you don't specify a value, the request would return up to 50 items.
    :type limit: integer
    """
    pass

def describe_subscription_filters(logGroupName=None, filterNamePrefix=None, nextToken=None, limit=None):
    """
    :param logGroupName: [REQUIRED]
            The log group name for which subscription filters are to be listed.
            
    :type logGroupName: string
    :param filterNamePrefix: Will only return subscription filters that match the provided filterNamePrefix. If you don't specify a value, no prefix filter is applied.
    :type filterNamePrefix: string
    :param nextToken: A string token used for pagination that points to the next page of results. It must be a value obtained from the response of the previous request. The token expires after 24 hours.
    :type nextToken: string
    :param limit: The maximum number of results to return.
    :type limit: integer
    """
    pass

def filter_log_events(logGroupName=None, logStreamNames=None, startTime=None, endTime=None, filterPattern=None, nextToken=None, limit=None, interleaved=None):
    """
    :param logGroupName: [REQUIRED]
            The name of the log group to query.
            
    :type logGroupName: string
    :param logStreamNames: Optional list of log stream names within the specified log group to search. Defaults to all the log streams in the log group.
            (string) --
            
    :type logStreamNames: list
    :param startTime: A point in time expressed as the number of milliseconds since Jan 1, 1970 00:00:00 UTC. If provided, events with a timestamp prior to this time are not returned.
    :type startTime: integer
    :param endTime: A point in time expressed as the number of milliseconds since Jan 1, 1970 00:00:00 UTC. If provided, events with a timestamp later than this time are not returned.
    :type endTime: integer
    :param filterPattern: A valid CloudWatch Logs filter pattern to use for filtering the response. If not provided, all the events are matched.
    :type filterPattern: string
    :param nextToken: A pagination token obtained from a FilterLogEvents response to continue paginating the FilterLogEvents results. This token is omitted from the response when there are no other events to display.
    :type nextToken: string
    :param limit: The maximum number of events to return in a page of results. Default is 10,000 events.
    :type limit: integer
    :param interleaved: If provided, the API will make a best effort to provide responses that contain events from multiple log streams within the log group interleaved in a single response. If not provided, all the matched log events in the first log stream will be searched first, then those in the next log stream, etc.
    :type interleaved: boolean
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    :param ClientMethod: The client method to presign for
    :type ClientMethod: string
    :param Params: The parameters normally passed to
            ClientMethod.
    :type Params: dict
    :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)
    :type ExpiresIn: int
    :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.
    :type HttpMethod: string
    """
    pass

def get_log_events(logGroupName=None, logStreamName=None, startTime=None, endTime=None, nextToken=None, limit=None, startFromHead=None):
    """
    :param logGroupName: [REQUIRED]
            The name of the log group to query.
            
    :type logGroupName: string
    :param logStreamName: [REQUIRED]
            The name of the log stream to query.
            
    :type logStreamName: string
    :param startTime: A point in time expressed as the number of milliseconds since Jan 1, 1970 00:00:00 UTC.
    :type startTime: integer
    :param endTime: A point in time expressed as the number of milliseconds since Jan 1, 1970 00:00:00 UTC.
    :type endTime: integer
    :param nextToken: A string token used for pagination that points to the next page of results. It must be a value obtained from the nextForwardToken or nextBackwardToken fields in the response of the previous GetLogEvents request.
    :type nextToken: string
    :param limit: The maximum number of log events returned in the response. If you don't specify a value, the request would return as many log events as can fit in a response size of 1MB, up to 10,000 log events.
    :type limit: integer
    :param startFromHead: If set to true, the earliest log events would be returned first. The default is false (the latest log events are returned first).
    :type startFromHead: boolean
    """
    pass

def get_paginator(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            Raises OperationNotPageableErrorRaised if the operation is not
            pageable. You can use the client.can_paginate method to
            check if an operation is pageable.
            Return typeL{botocore.paginate.Paginator}
            ReturnsA paginator object.
            
    :type operation_name: string
    """
    pass

def get_waiter():
    """
    """
    pass

def put_destination(destinationName=None, targetArn=None, roleArn=None):
    """
    :param destinationName: [REQUIRED]
            A name for the destination.
            
    :type destinationName: string
    :param targetArn: [REQUIRED]
            The ARN of an Amazon Kinesis stream to deliver matching log events to.
            
    :type targetArn: string
    :param roleArn: [REQUIRED]
            The ARN of an IAM role that grants CloudWatch Logs permissions to do Amazon Kinesis PutRecord requests on the destination stream.
            
    :type roleArn: string
    """
    pass

def put_destination_policy(destinationName=None, accessPolicy=None):
    """
    :param destinationName: [REQUIRED]
            A name for an existing destination.
            
    :type destinationName: string
    :param accessPolicy: [REQUIRED]
            An IAM policy document that authorizes cross-account users to deliver their log events to associated destination.
            
    :type accessPolicy: string
    """
    pass

def put_log_events(logGroupName=None, logStreamName=None, logEvents=None, sequenceToken=None):
    """
    :param logGroupName: [REQUIRED]
            The name of the log group to put log events to.
            
    :type logGroupName: string
    :param logStreamName: [REQUIRED]
            The name of the log stream to put log events to.
            
    :type logStreamName: string
    :param logEvents: [REQUIRED]
            A list of log events belonging to a log stream.
            (dict) --A log event is a record of some activity that was recorded by the application or resource being monitored. The log event record that CloudWatch Logs understands contains two properties: the timestamp of when the event occurred, and the raw event message.
            timestamp (integer) -- [REQUIRED]A point in time expressed as the number of milliseconds since Jan 1, 1970 00:00:00 UTC.
            message (string) -- [REQUIRED]
            
    :type logEvents: list
    :param sequenceToken: A string token that must be obtained from the response of the previous PutLogEvents request.
    :type sequenceToken: string
    """
    pass

def put_metric_filter(logGroupName=None, filterName=None, filterPattern=None, metricTransformations=None):
    """
    :param logGroupName: [REQUIRED]
            The name of the log group to associate the metric filter with.
            
    :type logGroupName: string
    :param filterName: [REQUIRED]
            A name for the metric filter.
            
    :type filterName: string
    :param filterPattern: [REQUIRED]
            A valid CloudWatch Logs filter pattern for extracting metric data out of ingested log events.
            
    :type filterPattern: string
    :param metricTransformations: [REQUIRED]
            A collection of information needed to define how metric data gets emitted.
            (dict) --
            metricName (string) -- [REQUIRED]Name of the metric.
            metricNamespace (string) -- [REQUIRED]Namespace to which the metric belongs.
            metricValue (string) -- [REQUIRED]A string representing a value to publish to this metric when a filter pattern matches a log event.
            defaultValue (float) --(Optional) A default value to emit when a filter pattern does not match a log event. Can be null.
            
            
    :type metricTransformations: list
    """
    pass

def put_retention_policy(logGroupName=None, retentionInDays=None):
    """
    :param logGroupName: [REQUIRED]
            The name of the log group to associate the retention policy with.
            
    :type logGroupName: string
    :param retentionInDays: [REQUIRED]
            Specifies the number of days you want to retain log events in the specified log group. Possible values are: 1, 3, 5, 7, 14, 30, 60, 90, 120, 150, 180, 365, 400, 545, 731, 1827, 3653.
            
    :type retentionInDays: integer
    """
    pass

def put_subscription_filter(logGroupName=None, filterName=None, filterPattern=None, destinationArn=None, roleArn=None):
    """
    :param logGroupName: [REQUIRED]
            The name of the log group to associate the subscription filter with.
            
    :type logGroupName: string
    :param filterName: [REQUIRED]
            A name for the subscription filter.
            
    :type filterName: string
    :param filterPattern: [REQUIRED]
            A valid CloudWatch Logs filter pattern for subscribing to a filtered stream of log events.
            
    :type filterPattern: string
    :param destinationArn: [REQUIRED]
            The ARN of the destination to deliver matching log events to. Currently, the supported destinations are:
            An Amazon Kinesis stream belonging to the same account as the subscription filter, for same-account delivery.
            A logical destination (used via an ARN of Destination ) belonging to a different account, for cross-account delivery.
            An Amazon Kinesis Firehose stream belonging to the same account as the subscription filter, for same-account delivery.
            An AWS Lambda function belonging to the same account as the subscription filter, for same-account delivery.
            
    :type destinationArn: string
    :param roleArn: The ARN of an IAM role that grants CloudWatch Logs permissions to deliver ingested log events to the destination stream. You don't need to provide the ARN when you are working with a logical destination (used via an ARN of Destination ) for cross-account delivery.
    :type roleArn: string
    """
    pass

def test_metric_filter(filterPattern=None, logEventMessages=None):
    """
    :param filterPattern: [REQUIRED]
            A symbolic description of how CloudWatch Logs should interpret the data in each log event. For example, a log event may contain timestamps, IP addresses, strings, and so on. You use the filter pattern to specify what to look for in the log event message.
            
    :type filterPattern: string
    :param logEventMessages: [REQUIRED]
            A list of log event messages to test.
            (string) --
            
    :type logEventMessages: list
    """
    pass




"""
The MIT License (MIT)

Copyright (c) 2016 Gehad Shaat

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


def add_tags_to_resource(ResourceArn=None, Tags=None):
    """
    :param ResourceArn: [REQUIRED]
            The Amazon Resource Name (ARN) of the AWS DMS resource the tag is to be added to. AWS DMS resources include a replication instance, endpoint, and a replication task.
            
    :type ResourceArn: string
    :param Tags: [REQUIRED]
            The tag to be assigned to the DMS resource.
            (dict) --
            Key (string) --A key is the required name of the tag. The string value can be from 1 to 128 Unicode characters in length and cannot be prefixed with 'aws:' or 'dms:'. The string can only contain only the set of Unicode letters, digits, white-space, '_', '.', '/', '=', '+', '-' (Java regex: '^([\p{L}\p{Z}\p{N}_.:/=+\-]*)$').
            Value (string) --A value is the optional value of the tag. The string value can be from 1 to 256 Unicode characters in length and cannot be prefixed with 'aws:' or 'dms:'. The string can only contain only the set of Unicode letters, digits, white-space, '_', '.', '/', '=', '+', '-' (Java regex: '^([\p{L}\p{Z}\p{N}_.:/=+\-]*)$').
            
            
    :type Tags: list
    """
    pass

def can_paginate(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            ReturnsTrue if the operation can be paginated,
            False otherwise.
            
    :type operation_name: string
    """
    pass

def create_endpoint(EndpointIdentifier=None, EndpointType=None, EngineName=None, Username=None, Password=None, ServerName=None, Port=None, DatabaseName=None, ExtraConnectionAttributes=None, KmsKeyId=None, Tags=None, CertificateArn=None, SslMode=None):
    """
    :param EndpointIdentifier: [REQUIRED]
            The database endpoint identifier. Identifiers must begin with a letter; must contain only ASCII letters, digits, and hyphens; and must not end with a hyphen or contain two consecutive hyphens.
            
    :type EndpointIdentifier: string
    :param EndpointType: [REQUIRED]
            The type of endpoint.
            
    :type EndpointType: string
    :param EngineName: [REQUIRED]
            The type of engine for the endpoint. Valid values include MYSQL, ORACLE, POSTGRES, MARIADB, AURORA, REDSHIFT, and SQLSERVER.
            
    :type EngineName: string
    :param Username: [REQUIRED]
            The user name to be used to login to the endpoint database.
            
    :type Username: string
    :param Password: [REQUIRED]
            The password to be used to login to the endpoint database.
            
    :type Password: string
    :param ServerName: [REQUIRED]
            The name of the server where the endpoint database resides.
            
    :type ServerName: string
    :param Port: [REQUIRED]
            The port used by the endpoint database.
            
    :type Port: integer
    :param DatabaseName: The name of the endpoint database.
    :type DatabaseName: string
    :param ExtraConnectionAttributes: Additional attributes associated with the connection.
    :type ExtraConnectionAttributes: string
    :param KmsKeyId: The KMS key identifier that will be used to encrypt the connection parameters. If you do not specify a value for the KmsKeyId parameter, then AWS DMS will use your default encryption key. AWS KMS creates the default encryption key for your AWS account. Your AWS account has a different default encryption key for each AWS region.
    :type KmsKeyId: string
    :param Tags: Tags to be added to the endpoint.
            (dict) --
            Key (string) --A key is the required name of the tag. The string value can be from 1 to 128 Unicode characters in length and cannot be prefixed with 'aws:' or 'dms:'. The string can only contain only the set of Unicode letters, digits, white-space, '_', '.', '/', '=', '+', '-' (Java regex: '^([\p{L}\p{Z}\p{N}_.:/=+\-]*)$').
            Value (string) --A value is the optional value of the tag. The string value can be from 1 to 256 Unicode characters in length and cannot be prefixed with 'aws:' or 'dms:'. The string can only contain only the set of Unicode letters, digits, white-space, '_', '.', '/', '=', '+', '-' (Java regex: '^([\p{L}\p{Z}\p{N}_.:/=+\-]*)$').
            
            
    :type Tags: list
    :param CertificateArn: The Amazon Resource Number (ARN) for the certificate.
    :type CertificateArn: string
    :param SslMode: The SSL mode to use for the SSL connection.
            SSL mode can be one of four values: none, require, verify-ca, verify-full.
            The default value is none.
            
    :type SslMode: string
    """
    pass

def create_replication_instance(ReplicationInstanceIdentifier=None, AllocatedStorage=None, ReplicationInstanceClass=None, VpcSecurityGroupIds=None, AvailabilityZone=None, ReplicationSubnetGroupIdentifier=None, PreferredMaintenanceWindow=None, MultiAZ=None, EngineVersion=None, AutoMinorVersionUpgrade=None, Tags=None, KmsKeyId=None, PubliclyAccessible=None):
    """
    :param ReplicationInstanceIdentifier: [REQUIRED]
            The replication instance identifier. This parameter is stored as a lowercase string.
            Constraints:
            Must contain from 1 to 63 alphanumeric characters or hyphens.
            First character must be a letter.
            Cannot end with a hyphen or contain two consecutive hyphens.
            Example: myrepinstance
            
    :type ReplicationInstanceIdentifier: string
    :param AllocatedStorage: The amount of storage (in gigabytes) to be initially allocated for the replication instance.
    :type AllocatedStorage: integer
    :param ReplicationInstanceClass: [REQUIRED]
            The compute and memory capacity of the replication instance as specified by the replication instance class.
            Valid Values: dms.t2.micro | dms.t2.small | dms.t2.medium | dms.t2.large | dms.c4.large | dms.c4.xlarge | dms.c4.2xlarge | dms.c4.4xlarge
            
    :type ReplicationInstanceClass: string
    :param VpcSecurityGroupIds: Specifies the VPC security group to be used with the replication instance. The VPC security group must work with the VPC containing the replication instance.
            (string) --
            
    :type VpcSecurityGroupIds: list
    :param AvailabilityZone: The EC2 Availability Zone that the replication instance will be created in.
            Default: A random, system-chosen Availability Zone in the endpoint's region.
            Example: us-east-1d
            
    :type AvailabilityZone: string
    :param ReplicationSubnetGroupIdentifier: A subnet group to associate with the replication instance.
    :type ReplicationSubnetGroupIdentifier: string
    :param PreferredMaintenanceWindow: The weekly time range during which system maintenance can occur, in Universal Coordinated Time (UTC).
            Format: ddd:hh24:mi-ddd:hh24:mi
            Default: A 30-minute window selected at random from an 8-hour block of time per region, occurring on a random day of the week.
            Valid Days: Mon, Tue, Wed, Thu, Fri, Sat, Sun
            Constraints: Minimum 30-minute window.
            
    :type PreferredMaintenanceWindow: string
    :param MultiAZ: Specifies if the replication instance is a Multi-AZ deployment. You cannot set the AvailabilityZone parameter if the Multi-AZ parameter is set to true .
    :type MultiAZ: boolean
    :param EngineVersion: The engine version number of the replication instance.
    :type EngineVersion: string
    :param AutoMinorVersionUpgrade: Indicates that minor engine upgrades will be applied automatically to the replication instance during the maintenance window.
            Default: true
            
    :type AutoMinorVersionUpgrade: boolean
    :param Tags: Tags to be associated with the replication instance.
            (dict) --
            Key (string) --A key is the required name of the tag. The string value can be from 1 to 128 Unicode characters in length and cannot be prefixed with 'aws:' or 'dms:'. The string can only contain only the set of Unicode letters, digits, white-space, '_', '.', '/', '=', '+', '-' (Java regex: '^([\p{L}\p{Z}\p{N}_.:/=+\-]*)$').
            Value (string) --A value is the optional value of the tag. The string value can be from 1 to 256 Unicode characters in length and cannot be prefixed with 'aws:' or 'dms:'. The string can only contain only the set of Unicode letters, digits, white-space, '_', '.', '/', '=', '+', '-' (Java regex: '^([\p{L}\p{Z}\p{N}_.:/=+\-]*)$').
            
            
    :type Tags: list
    :param KmsKeyId: The KMS key identifier that will be used to encrypt the content on the replication instance. If you do not specify a value for the KmsKeyId parameter, then AWS DMS will use your default encryption key. AWS KMS creates the default encryption key for your AWS account. Your AWS account has a different default encryption key for each AWS region.
    :type KmsKeyId: string
    :param PubliclyAccessible: Specifies the accessibility options for the replication instance. A value of true represents an instance with a public IP address. A value of false represents an instance with a private IP address. The default value is true .
    :type PubliclyAccessible: boolean
    """
    pass

def create_replication_subnet_group(ReplicationSubnetGroupIdentifier=None, ReplicationSubnetGroupDescription=None, SubnetIds=None, Tags=None):
    """
    :param ReplicationSubnetGroupIdentifier: [REQUIRED]
            The name for the replication subnet group. This value is stored as a lowercase string.
            Constraints: Must contain no more than 255 alphanumeric characters, periods, spaces, underscores, or hyphens. Must not be 'default'.
            Example: mySubnetgroup
            
    :type ReplicationSubnetGroupIdentifier: string
    :param ReplicationSubnetGroupDescription: [REQUIRED]
            The description for the subnet group.
            
    :type ReplicationSubnetGroupDescription: string
    :param SubnetIds: [REQUIRED]
            The EC2 subnet IDs for the subnet group.
            (string) --
            
    :type SubnetIds: list
    :param Tags: The tag to be assigned to the subnet group.
            (dict) --
            Key (string) --A key is the required name of the tag. The string value can be from 1 to 128 Unicode characters in length and cannot be prefixed with 'aws:' or 'dms:'. The string can only contain only the set of Unicode letters, digits, white-space, '_', '.', '/', '=', '+', '-' (Java regex: '^([\p{L}\p{Z}\p{N}_.:/=+\-]*)$').
            Value (string) --A value is the optional value of the tag. The string value can be from 1 to 256 Unicode characters in length and cannot be prefixed with 'aws:' or 'dms:'. The string can only contain only the set of Unicode letters, digits, white-space, '_', '.', '/', '=', '+', '-' (Java regex: '^([\p{L}\p{Z}\p{N}_.:/=+\-]*)$').
            
            
    :type Tags: list
    """
    pass

def create_replication_task(ReplicationTaskIdentifier=None, SourceEndpointArn=None, TargetEndpointArn=None, ReplicationInstanceArn=None, MigrationType=None, TableMappings=None, ReplicationTaskSettings=None, CdcStartTime=None, Tags=None):
    """
    :param ReplicationTaskIdentifier: [REQUIRED]
            The replication task identifier.
            Constraints:
            Must contain from 1 to 63 alphanumeric characters or hyphens.
            First character must be a letter.
            Cannot end with a hyphen or contain two consecutive hyphens.
            
    :type ReplicationTaskIdentifier: string
    :param SourceEndpointArn: [REQUIRED]
            The Amazon Resource Name (ARN) string that uniquely identifies the endpoint.
            
    :type SourceEndpointArn: string
    :param TargetEndpointArn: [REQUIRED]
            The Amazon Resource Name (ARN) string that uniquely identifies the endpoint.
            
    :type TargetEndpointArn: string
    :param ReplicationInstanceArn: [REQUIRED]
            The Amazon Resource Name (ARN) of the replication instance.
            
    :type ReplicationInstanceArn: string
    :param MigrationType: [REQUIRED]
            The migration type.
            
    :type MigrationType: string
    :param TableMappings: [REQUIRED]
            The path of the JSON file that contains the table mappings. Preceed the path with 'file://'.
            For example, --table-mappings file://mappingfile.json
            
    :type TableMappings: string
    :param ReplicationTaskSettings: Settings for the task, such as target metadata settings.
    :type ReplicationTaskSettings: string
    :param CdcStartTime: The start time for the Change Data Capture (CDC) operation.
    :type CdcStartTime: datetime
    :param Tags: Tags to be added to the replication instance.
            (dict) --
            Key (string) --A key is the required name of the tag. The string value can be from 1 to 128 Unicode characters in length and cannot be prefixed with 'aws:' or 'dms:'. The string can only contain only the set of Unicode letters, digits, white-space, '_', '.', '/', '=', '+', '-' (Java regex: '^([\p{L}\p{Z}\p{N}_.:/=+\-]*)$').
            Value (string) --A value is the optional value of the tag. The string value can be from 1 to 256 Unicode characters in length and cannot be prefixed with 'aws:' or 'dms:'. The string can only contain only the set of Unicode letters, digits, white-space, '_', '.', '/', '=', '+', '-' (Java regex: '^([\p{L}\p{Z}\p{N}_.:/=+\-]*)$').
            
            
    :type Tags: list
    """
    pass

def delete_certificate(CertificateArn=None):
    """
    :param CertificateArn: [REQUIRED]
            the Amazon Resource Name (ARN) of the deleted certificate.
            Return typedict
            ReturnsResponse Syntax{
              'Certificate': {
                'CertificateIdentifier': 'string',
                'CertificateCreationDate': datetime(2015, 1, 1),
                'CertificatePem': 'string',
                'CertificateArn': 'string',
                'CertificateOwner': 'string',
                'ValidFromDate': datetime(2015, 1, 1),
                'ValidToDate': datetime(2015, 1, 1),
                'SigningAlgorithm': 'string',
                'KeyLength': 123
              }
            }
            Response Structure
            (dict) --
            Certificate (dict) --The SSL certificate.
            CertificateIdentifier (string) --The customer-assigned name of the certificate. Valid characters are [A-z_0-9].
            CertificateCreationDate (datetime) --the date the certificate was created.
            CertificatePem (string) --The contents of the .pem X.509 certificate file.
            CertificateArn (string) --The Amazon Resource Name (ARN) for the certificate.
            CertificateOwner (string) --The owner of the certificate.
            ValidFromDate (datetime) --The beginning date the certificate is valid.
            ValidToDate (datetime) --the final date the certificate is valid.
            SigningAlgorithm (string) --The signing algorithm for the certificate.
            KeyLength (integer) --The key length of the cryptographic algorithm being used.
            
            
            
    :type CertificateArn: string
    """
    pass

def delete_endpoint(EndpointArn=None):
    """
    :param EndpointArn: [REQUIRED]
            The Amazon Resource Name (ARN) string that uniquely identifies the endpoint.
            Return typedict
            ReturnsResponse Syntax{
              'Endpoint': {
                'EndpointIdentifier': 'string',
                'EndpointType': 'source'|'target',
                'EngineName': 'string',
                'Username': 'string',
                'ServerName': 'string',
                'Port': 123,
                'DatabaseName': 'string',
                'ExtraConnectionAttributes': 'string',
                'Status': 'string',
                'KmsKeyId': 'string',
                'EndpointArn': 'string',
                'CertificateArn': 'string',
                'SslMode': 'none'|'require'|'verify-ca'|'verify-full'
              }
            }
            Response Structure
            (dict) --
            Endpoint (dict) --The endpoint that was deleted.
            EndpointIdentifier (string) --The database endpoint identifier. Identifiers must begin with a letter; must contain only ASCII letters, digits, and hyphens; and must not end with a hyphen or contain two consecutive hyphens.
            EndpointType (string) --The type of endpoint.
            EngineName (string) --The database engine name.
            Username (string) --The user name used to connect to the endpoint.
            ServerName (string) --The name of the server at the endpoint.
            Port (integer) --The port value used to access the endpoint.
            DatabaseName (string) --The name of the database at the endpoint.
            ExtraConnectionAttributes (string) --Additional connection attributes used to connect to the endpoint.
            Status (string) --The status of the endpoint.
            KmsKeyId (string) --The KMS key identifier that will be used to encrypt the connection parameters. If you do not specify a value for the KmsKeyId parameter, then AWS DMS will use your default encryption key. AWS KMS creates the default encryption key for your AWS account. Your AWS account has a different default encryption key for each AWS region.
            EndpointArn (string) --The Amazon Resource Name (ARN) string that uniquely identifies the endpoint.
            CertificateArn (string) --The Amazon Resource Name (ARN) used for SSL connection to the endpoint.
            SslMode (string) --The SSL mode used to connect to the endpoint.
            SSL mode can be one of four values: none, require, verify-ca, verify-full.
            The default value is none.
            
            
            
    :type EndpointArn: string
    """
    pass

def delete_replication_instance(ReplicationInstanceArn=None):
    """
    :param ReplicationInstanceArn: [REQUIRED]
            The Amazon Resource Name (ARN) of the replication instance to be deleted.
            Return typedict
            ReturnsResponse Syntax{
              'ReplicationInstance': {
                'ReplicationInstanceIdentifier': 'string',
                'ReplicationInstanceClass': 'string',
                'ReplicationInstanceStatus': 'string',
                'AllocatedStorage': 123,
                'InstanceCreateTime': datetime(2015, 1, 1),
                'VpcSecurityGroups': [
                  {
                    'VpcSecurityGroupId': 'string',
                    'Status': 'string'
                  },
                ],
                'AvailabilityZone': 'string',
                'ReplicationSubnetGroup': {
                  'ReplicationSubnetGroupIdentifier': 'string',
                  'ReplicationSubnetGroupDescription': 'string',
                  'VpcId': 'string',
                  'SubnetGroupStatus': 'string',
                  'Subnets': [
                    {
                      'SubnetIdentifier': 'string',
                      'SubnetAvailabilityZone': {
                        'Name': 'string'
                      },
                      'SubnetStatus': 'string'
                    },
                  ]
                },
                'PreferredMaintenanceWindow': 'string',
                'PendingModifiedValues': {
                  'ReplicationInstanceClass': 'string',
                  'AllocatedStorage': 123,
                  'MultiAZ': True|False,
                  'EngineVersion': 'string'
                },
                'MultiAZ': True|False,
                'EngineVersion': 'string',
                'AutoMinorVersionUpgrade': True|False,
                'KmsKeyId': 'string',
                'ReplicationInstanceArn': 'string',
                'ReplicationInstancePublicIpAddress': 'string',
                'ReplicationInstancePrivateIpAddress': 'string',
                'ReplicationInstancePublicIpAddresses': [
                  'string',
                ],
                'ReplicationInstancePrivateIpAddresses': [
                  'string',
                ],
                'PubliclyAccessible': True|False
              }
            }
            Response Structure
            (dict) --
            ReplicationInstance (dict) --The replication instance that was deleted.
            ReplicationInstanceIdentifier (string) --The replication instance identifier. This parameter is stored as a lowercase string.
            Constraints:
            Must contain from 1 to 63 alphanumeric characters or hyphens.
            First character must be a letter.
            Cannot end with a hyphen or contain two consecutive hyphens.
            Example: myrepinstance
            ReplicationInstanceClass (string) --The compute and memory capacity of the replication instance.
            Valid Values: dms.t2.micro | dms.t2.small | dms.t2.medium | dms.t2.large | dms.c4.large | dms.c4.xlarge | dms.c4.2xlarge | dms.c4.4xlarge
            ReplicationInstanceStatus (string) --The status of the replication instance.
            AllocatedStorage (integer) --The amount of storage (in gigabytes) that is allocated for the replication instance.
            InstanceCreateTime (datetime) --The time the replication instance was created.
            VpcSecurityGroups (list) --The VPC security group for the instance.
            (dict) --
            VpcSecurityGroupId (string) --The VPC security group Id.
            Status (string) --The status of the VPC security group.
            
            AvailabilityZone (string) --The Availability Zone for the instance.
            ReplicationSubnetGroup (dict) --The subnet group for the replication instance.
            ReplicationSubnetGroupIdentifier (string) --The identifier of the replication instance subnet group.
            ReplicationSubnetGroupDescription (string) --The description of the replication subnet group.
            VpcId (string) --The ID of the VPC.
            SubnetGroupStatus (string) --The status of the subnet group.
            Subnets (list) --The subnets that are in the subnet group.
            (dict) --
            SubnetIdentifier (string) --The subnet identifier.
            SubnetAvailabilityZone (dict) --The Availability Zone of the subnet.
            Name (string) --The name of the availability zone.
            SubnetStatus (string) --The status of the subnet.
            
            PreferredMaintenanceWindow (string) --The maintenance window times for the replication instance.
            PendingModifiedValues (dict) --The pending modification values.
            ReplicationInstanceClass (string) --The compute and memory capacity of the replication instance.
            Valid Values: dms.t2.micro | dms.t2.small | dms.t2.medium | dms.t2.large | dms.c4.large | dms.c4.xlarge | dms.c4.2xlarge | dms.c4.4xlarge
            AllocatedStorage (integer) --The amount of storage (in gigabytes) that is allocated for the replication instance.
            MultiAZ (boolean) --Specifies if the replication instance is a Multi-AZ deployment. You cannot set the AvailabilityZone parameter if the Multi-AZ parameter is set to true .
            EngineVersion (string) --The engine version number of the replication instance.
            MultiAZ (boolean) --Specifies if the replication instance is a Multi-AZ deployment. You cannot set the AvailabilityZone parameter if the Multi-AZ parameter is set to true .
            EngineVersion (string) --The engine version number of the replication instance.
            AutoMinorVersionUpgrade (boolean) --Boolean value indicating if minor version upgrades will be automatically applied to the instance.
            KmsKeyId (string) --The KMS key identifier that is used to encrypt the content on the replication instance. If you do not specify a value for the KmsKeyId parameter, then AWS DMS will use your default encryption key. AWS KMS creates the default encryption key for your AWS account. Your AWS account has a different default encryption key for each AWS region.
            ReplicationInstanceArn (string) --The Amazon Resource Name (ARN) of the replication instance.
            ReplicationInstancePublicIpAddress (string) --The public IP address of the replication instance.
            ReplicationInstancePrivateIpAddress (string) --The private IP address of the replication instance.
            ReplicationInstancePublicIpAddresses (list) --The public IP address of the replication instance.
            (string) --
            ReplicationInstancePrivateIpAddresses (list) --The private IP address of the replication instance.
            (string) --
            PubliclyAccessible (boolean) --Specifies the accessibility options for the replication instance. A value of true represents an instance with a public IP address. A value of false represents an instance with a private IP address. The default value is true .
            
            
            
    :type ReplicationInstanceArn: string
    """
    pass

def delete_replication_subnet_group(ReplicationSubnetGroupIdentifier=None):
    """
    :param ReplicationSubnetGroupIdentifier: [REQUIRED]
            The subnet group name of the replication instance.
            Return typedict
            ReturnsResponse Syntax{}
            Response Structure
            (dict) --
            
    :type ReplicationSubnetGroupIdentifier: string
    """
    pass

def delete_replication_task(ReplicationTaskArn=None):
    """
    :param ReplicationTaskArn: [REQUIRED]
            The Amazon Resource Name (ARN) of the replication task to be deleted.
            Return typedict
            ReturnsResponse Syntax{
              'ReplicationTask': {
                'ReplicationTaskIdentifier': 'string',
                'SourceEndpointArn': 'string',
                'TargetEndpointArn': 'string',
                'ReplicationInstanceArn': 'string',
                'MigrationType': 'full-load'|'cdc'|'full-load-and-cdc',
                'TableMappings': 'string',
                'ReplicationTaskSettings': 'string',
                'Status': 'string',
                'LastFailureMessage': 'string',
                'ReplicationTaskCreationDate': datetime(2015, 1, 1),
                'ReplicationTaskStartDate': datetime(2015, 1, 1),
                'ReplicationTaskArn': 'string',
                'ReplicationTaskStats': {
                  'FullLoadProgressPercent': 123,
                  'ElapsedTimeMillis': 123,
                  'TablesLoaded': 123,
                  'TablesLoading': 123,
                  'TablesQueued': 123,
                  'TablesErrored': 123
                }
              }
            }
            Response Structure
            (dict) --
            ReplicationTask (dict) --The deleted replication task.
            ReplicationTaskIdentifier (string) --The replication task identifier.
            Constraints:
            Must contain from 1 to 63 alphanumeric characters or hyphens.
            First character must be a letter.
            Cannot end with a hyphen or contain two consecutive hyphens.
            SourceEndpointArn (string) --The Amazon Resource Name (ARN) string that uniquely identifies the endpoint.
            TargetEndpointArn (string) --The Amazon Resource Name (ARN) string that uniquely identifies the endpoint.
            ReplicationInstanceArn (string) --The Amazon Resource Name (ARN) of the replication instance.
            MigrationType (string) --The type of migration.
            TableMappings (string) --Table mappings specified in the task.
            ReplicationTaskSettings (string) --The settings for the replication task.
            Status (string) --The status of the replication task.
            LastFailureMessage (string) --The last error (failure) message generated for the replication instance.
            ReplicationTaskCreationDate (datetime) --The date the replication task was created.
            ReplicationTaskStartDate (datetime) --The date the replication task is scheduled to start.
            ReplicationTaskArn (string) --The Amazon Resource Name (ARN) of the replication task.
            ReplicationTaskStats (dict) --The statistics for the task, including elapsed time, tables loaded, and table errors.
            FullLoadProgressPercent (integer) --The percent complete for the full load migration task.
            ElapsedTimeMillis (integer) --The elapsed time of the task, in milliseconds.
            TablesLoaded (integer) --The number of tables loaded for this task.
            TablesLoading (integer) --The number of tables currently loading for this task.
            TablesQueued (integer) --The number of tables queued for this task.
            TablesErrored (integer) --The number of errors that have occurred during this task.
            
            
            
    :type ReplicationTaskArn: string
    """
    pass

def describe_account_attributes():
    """
    """
    pass

def describe_certificates(Filters=None, MaxRecords=None, Marker=None):
    """
    :param Filters: Filters applied to the certificate described in the form of key-value pairs.
            (dict) --
            Name (string) -- [REQUIRED]The name of the filter.
            Values (list) -- [REQUIRED]The filter value.
            (string) --
            
            
    :type Filters: list
    :param MaxRecords: The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved.
            Default: 10
            
    :type MaxRecords: integer
    :param Marker: An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords .
    :type Marker: string
    """
    pass

def describe_connections(Filters=None, MaxRecords=None, Marker=None):
    """
    :param Filters: The filters applied to the connection.
            Valid filter names: endpoint-arn | replication-instance-arn
            (dict) --
            Name (string) -- [REQUIRED]The name of the filter.
            Values (list) -- [REQUIRED]The filter value.
            (string) --
            
            
    :type Filters: list
    :param MaxRecords: The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved.
            Default: 100
            Constraints: Minimum 20, maximum 100.
            
    :type MaxRecords: integer
    :param Marker: An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords .
    :type Marker: string
    """
    pass

def describe_endpoint_types(Filters=None, MaxRecords=None, Marker=None):
    """
    :param Filters: Filters applied to the describe action.
            Valid filter names: engine-name | endpoint-type
            (dict) --
            Name (string) -- [REQUIRED]The name of the filter.
            Values (list) -- [REQUIRED]The filter value.
            (string) --
            
            
    :type Filters: list
    :param MaxRecords: The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved.
            Default: 100
            Constraints: Minimum 20, maximum 100.
            
    :type MaxRecords: integer
    :param Marker: An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords .
    :type Marker: string
    """
    pass

def describe_endpoints(Filters=None, MaxRecords=None, Marker=None):
    """
    :param Filters: Filters applied to the describe action.
            Valid filter names: endpoint-arn | endpoint-type | endpoint-id | engine-name
            (dict) --
            Name (string) -- [REQUIRED]The name of the filter.
            Values (list) -- [REQUIRED]The filter value.
            (string) --
            
            
    :type Filters: list
    :param MaxRecords: The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved.
            Default: 100
            Constraints: Minimum 20, maximum 100.
            
    :type MaxRecords: integer
    :param Marker: An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords .
    :type Marker: string
    """
    pass

def describe_orderable_replication_instances(MaxRecords=None, Marker=None):
    """
    :param MaxRecords: The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved.
            Default: 100
            Constraints: Minimum 20, maximum 100.
            
    :type MaxRecords: integer
    :param Marker: An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords .
    :type Marker: string
    """
    pass

def describe_refresh_schemas_status(EndpointArn=None):
    """
    :param EndpointArn: [REQUIRED]
            The Amazon Resource Name (ARN) string that uniquely identifies the endpoint.
            Return typedict
            ReturnsResponse Syntax{
              'RefreshSchemasStatus': {
                'EndpointArn': 'string',
                'ReplicationInstanceArn': 'string',
                'Status': 'successful'|'failed'|'refreshing',
                'LastRefreshDate': datetime(2015, 1, 1),
                'LastFailureMessage': 'string'
              }
            }
            Response Structure
            (dict) --
            RefreshSchemasStatus (dict) --The status of the schema.
            EndpointArn (string) --The Amazon Resource Name (ARN) string that uniquely identifies the endpoint.
            ReplicationInstanceArn (string) --The Amazon Resource Name (ARN) of the replication instance.
            Status (string) --The status of the schema.
            LastRefreshDate (datetime) --The date the schema was last refreshed.
            LastFailureMessage (string) --The last failure message for the schema.
            
            
            
    :type EndpointArn: string
    """
    pass

def describe_replication_instances(Filters=None, MaxRecords=None, Marker=None):
    """
    :param Filters: Filters applied to the describe action.
            Valid filter names: replication-instance-arn | replication-instance-id | replication-instance-class | engine-version
            (dict) --
            Name (string) -- [REQUIRED]The name of the filter.
            Values (list) -- [REQUIRED]The filter value.
            (string) --
            
            
    :type Filters: list
    :param MaxRecords: The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved.
            Default: 100
            Constraints: Minimum 20, maximum 100.
            
    :type MaxRecords: integer
    :param Marker: An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords .
    :type Marker: string
    """
    pass

def describe_replication_subnet_groups(Filters=None, MaxRecords=None, Marker=None):
    """
    :param Filters: Filters applied to the describe action.
            (dict) --
            Name (string) -- [REQUIRED]The name of the filter.
            Values (list) -- [REQUIRED]The filter value.
            (string) --
            
            
    :type Filters: list
    :param MaxRecords: The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved.
            Default: 100
            Constraints: Minimum 20, maximum 100.
            
    :type MaxRecords: integer
    :param Marker: An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords .
    :type Marker: string
    """
    pass

def describe_replication_tasks(Filters=None, MaxRecords=None, Marker=None):
    """
    :param Filters: Filters applied to the describe action.
            Valid filter names: replication-task-arn | replication-task-id | migration-type | endpoint-arn | replication-instance-arn
            (dict) --
            Name (string) -- [REQUIRED]The name of the filter.
            Values (list) -- [REQUIRED]The filter value.
            (string) --
            
            
    :type Filters: list
    :param MaxRecords: The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved.
            Default: 100
            Constraints: Minimum 20, maximum 100.
            
    :type MaxRecords: integer
    :param Marker: An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords .
    :type Marker: string
    """
    pass

def describe_schemas(EndpointArn=None, MaxRecords=None, Marker=None):
    """
    :param EndpointArn: [REQUIRED]
            The Amazon Resource Name (ARN) string that uniquely identifies the endpoint.
            
    :type EndpointArn: string
    :param MaxRecords: The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved.
            Default: 100
            Constraints: Minimum 20, maximum 100.
            
    :type MaxRecords: integer
    :param Marker: An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords .
    :type Marker: string
    """
    pass

def describe_table_statistics(ReplicationTaskArn=None, MaxRecords=None, Marker=None):
    """
    :param ReplicationTaskArn: [REQUIRED]
            The Amazon Resource Name (ARN) of the replication task.
            
    :type ReplicationTaskArn: string
    :param MaxRecords: The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved.
            Default: 100
            Constraints: Minimum 20, maximum 100.
            
    :type MaxRecords: integer
    :param Marker: An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords .
    :type Marker: string
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    :param ClientMethod: The client method to presign for
    :type ClientMethod: string
    :param Params: The parameters normally passed to
            ClientMethod.
    :type Params: dict
    :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)
    :type ExpiresIn: int
    :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.
    :type HttpMethod: string
    """
    pass

def get_paginator(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            Raises OperationNotPageableErrorRaised if the operation is not
            pageable. You can use the client.can_paginate method to
            check if an operation is pageable.
            Return typeL{botocore.paginate.Paginator}
            ReturnsA paginator object.
            
    :type operation_name: string
    """
    pass

def get_waiter():
    """
    """
    pass

def import_certificate(CertificateIdentifier=None, CertificatePem=None):
    """
    :param CertificateIdentifier: [REQUIRED]
            The customer-assigned name of the certificate. Valid characters are [A-z_0-9].
            
    :type CertificateIdentifier: string
    :param CertificatePem: The contents of the .pem X.509 certificate file.
    :type CertificatePem: string
    """
    pass

def list_tags_for_resource(ResourceArn=None):
    """
    :param ResourceArn: [REQUIRED]
            The Amazon Resource Name (ARN) string that uniquely identifies the AWS DMS resource.
            Return typedict
            ReturnsResponse Syntax{
              'TagList': [
                {
                  'Key': 'string',
                  'Value': 'string'
                },
              ]
            }
            Response Structure
            (dict) --
            TagList (list) --A list of tags for the resource.
            (dict) --
            Key (string) --A key is the required name of the tag. The string value can be from 1 to 128 Unicode characters in length and cannot be prefixed with 'aws:' or 'dms:'. The string can only contain only the set of Unicode letters, digits, white-space, '_', '.', '/', '=', '+', '-' (Java regex: '^([\p{L}\p{Z}\p{N}_.:/=+\-]*)$').
            Value (string) --A value is the optional value of the tag. The string value can be from 1 to 256 Unicode characters in length and cannot be prefixed with 'aws:' or 'dms:'. The string can only contain only the set of Unicode letters, digits, white-space, '_', '.', '/', '=', '+', '-' (Java regex: '^([\p{L}\p{Z}\p{N}_.:/=+\-]*)$').
            
            
            
    :type ResourceArn: string
    """
    pass

def modify_endpoint(EndpointArn=None, EndpointIdentifier=None, EndpointType=None, EngineName=None, Username=None, Password=None, ServerName=None, Port=None, DatabaseName=None, ExtraConnectionAttributes=None, CertificateArn=None, SslMode=None):
    """
    :param EndpointArn: [REQUIRED]
            The Amazon Resource Name (ARN) string that uniquely identifies the endpoint.
            
    :type EndpointArn: string
    :param EndpointIdentifier: The database endpoint identifier. Identifiers must begin with a letter; must contain only ASCII letters, digits, and hyphens; and must not end with a hyphen or contain two consecutive hyphens.
    :type EndpointIdentifier: string
    :param EndpointType: The type of endpoint.
    :type EndpointType: string
    :param EngineName: The type of engine for the endpoint. Valid values include MYSQL, ORACLE, POSTGRES, MARIADB, AURORA, REDSHIFT, and SQLSERVER.
    :type EngineName: string
    :param Username: The user name to be used to login to the endpoint database.
    :type Username: string
    :param Password: The password to be used to login to the endpoint database.
    :type Password: string
    :param ServerName: The name of the server where the endpoint database resides.
    :type ServerName: string
    :param Port: The port used by the endpoint database.
    :type Port: integer
    :param DatabaseName: The name of the endpoint database.
    :type DatabaseName: string
    :param ExtraConnectionAttributes: Additional attributes associated with the connection.
    :type ExtraConnectionAttributes: string
    :param CertificateArn: The Amazon Resource Name (ARN) of the certificate used for SSL connection.
    :type CertificateArn: string
    :param SslMode: The SSL mode to be used.
            SSL mode can be one of four values: none, require, verify-ca, verify-full.
            The default value is none.
            
    :type SslMode: string
    """
    pass

def modify_replication_instance(ReplicationInstanceArn=None, AllocatedStorage=None, ApplyImmediately=None, ReplicationInstanceClass=None, VpcSecurityGroupIds=None, PreferredMaintenanceWindow=None, MultiAZ=None, EngineVersion=None, AllowMajorVersionUpgrade=None, AutoMinorVersionUpgrade=None, ReplicationInstanceIdentifier=None):
    """
    :param ReplicationInstanceArn: [REQUIRED]
            The Amazon Resource Name (ARN) of the replication instance.
            
    :type ReplicationInstanceArn: string
    :param AllocatedStorage: The amount of storage (in gigabytes) to be allocated for the replication instance.
    :type AllocatedStorage: integer
    :param ApplyImmediately: Indicates whether the changes should be applied immediately or during the next maintenance window.
    :type ApplyImmediately: boolean
    :param ReplicationInstanceClass: The compute and memory capacity of the replication instance.
            Valid Values: dms.t2.micro | dms.t2.small | dms.t2.medium | dms.t2.large | dms.c4.large | dms.c4.xlarge | dms.c4.2xlarge | dms.c4.4xlarge
            
    :type ReplicationInstanceClass: string
    :param VpcSecurityGroupIds: Specifies the VPC security group to be used with the replication instance. The VPC security group must work with the VPC containing the replication instance.
            (string) --
            
    :type VpcSecurityGroupIds: list
    :param PreferredMaintenanceWindow: The weekly time range (in UTC) during which system maintenance can occur, which might result in an outage. Changing this parameter does not result in an outage, except in the following situation, and the change is asynchronously applied as soon as possible. If moving this window to the current time, there must be at least 30 minutes between the current time and end of the window to ensure pending changes are applied.
            Default: Uses existing setting
            Format: ddd:hh24:mi-ddd:hh24:mi
            Valid Days: Mon | Tue | Wed | Thu | Fri | Sat | Sun
            Constraints: Must be at least 30 minutes
            
    :type PreferredMaintenanceWindow: string
    :param MultiAZ: Specifies if the replication instance is a Multi-AZ deployment. You cannot set the AvailabilityZone parameter if the Multi-AZ parameter is set to true .
    :type MultiAZ: boolean
    :param EngineVersion: The engine version number of the replication instance.
    :type EngineVersion: string
    :param AllowMajorVersionUpgrade: Indicates that major version upgrades are allowed. Changing this parameter does not result in an outage and the change is asynchronously applied as soon as possible.
            Constraints: This parameter must be set to true when specifying a value for the EngineVersion parameter that is a different major version than the replication instance's current version.
            
    :type AllowMajorVersionUpgrade: boolean
    :param AutoMinorVersionUpgrade: Indicates that minor version upgrades will be applied automatically to the replication instance during the maintenance window. Changing this parameter does not result in an outage except in the following case and the change is asynchronously applied as soon as possible. An outage will result if this parameter is set to true during the maintenance window, and a newer minor version is available, and AWS DMS has enabled auto patching for that engine version.
    :type AutoMinorVersionUpgrade: boolean
    :param ReplicationInstanceIdentifier: The replication instance identifier. This parameter is stored as a lowercase string.
    :type ReplicationInstanceIdentifier: string
    """
    pass

def modify_replication_subnet_group(ReplicationSubnetGroupIdentifier=None, ReplicationSubnetGroupDescription=None, SubnetIds=None):
    """
    :param ReplicationSubnetGroupIdentifier: [REQUIRED]
            The name of the replication instance subnet group.
            
    :type ReplicationSubnetGroupIdentifier: string
    :param ReplicationSubnetGroupDescription: The description of the replication instance subnet group.
    :type ReplicationSubnetGroupDescription: string
    :param SubnetIds: [REQUIRED]
            A list of subnet IDs.
            (string) --
            
    :type SubnetIds: list
    """
    pass

def refresh_schemas(EndpointArn=None, ReplicationInstanceArn=None):
    """
    :param EndpointArn: [REQUIRED]
            The Amazon Resource Name (ARN) string that uniquely identifies the endpoint.
            
    :type EndpointArn: string
    :param ReplicationInstanceArn: [REQUIRED]
            The Amazon Resource Name (ARN) of the replication instance.
            
    :type ReplicationInstanceArn: string
    """
    pass

def remove_tags_from_resource(ResourceArn=None, TagKeys=None):
    """
    :param ResourceArn: [REQUIRED]
            The Amazon Resource Name (ARN) of the AWS DMS resource the tag is to be removed from.
            
    :type ResourceArn: string
    :param TagKeys: [REQUIRED]
            The tag key (name) of the tag to be removed.
            (string) --
            
    :type TagKeys: list
    """
    pass

def start_replication_task(ReplicationTaskArn=None, StartReplicationTaskType=None, CdcStartTime=None):
    """
    :param ReplicationTaskArn: [REQUIRED]
            The Amazon Resource Number (ARN) of the replication task to be started.
            
    :type ReplicationTaskArn: string
    :param StartReplicationTaskType: [REQUIRED]
            The type of replication task.
            
    :type StartReplicationTaskType: string
    :param CdcStartTime: The start time for the Change Data Capture (CDC) operation.
    :type CdcStartTime: datetime
    """
    pass

def stop_replication_task(ReplicationTaskArn=None):
    """
    :param ReplicationTaskArn: [REQUIRED]
            The Amazon Resource Number(ARN) of the replication task to be stopped.
            Return typedict
            ReturnsResponse Syntax{
              'ReplicationTask': {
                'ReplicationTaskIdentifier': 'string',
                'SourceEndpointArn': 'string',
                'TargetEndpointArn': 'string',
                'ReplicationInstanceArn': 'string',
                'MigrationType': 'full-load'|'cdc'|'full-load-and-cdc',
                'TableMappings': 'string',
                'ReplicationTaskSettings': 'string',
                'Status': 'string',
                'LastFailureMessage': 'string',
                'ReplicationTaskCreationDate': datetime(2015, 1, 1),
                'ReplicationTaskStartDate': datetime(2015, 1, 1),
                'ReplicationTaskArn': 'string',
                'ReplicationTaskStats': {
                  'FullLoadProgressPercent': 123,
                  'ElapsedTimeMillis': 123,
                  'TablesLoaded': 123,
                  'TablesLoading': 123,
                  'TablesQueued': 123,
                  'TablesErrored': 123
                }
              }
            }
            Response Structure
            (dict) --
            ReplicationTask (dict) --The replication task stopped.
            ReplicationTaskIdentifier (string) --The replication task identifier.
            Constraints:
            Must contain from 1 to 63 alphanumeric characters or hyphens.
            First character must be a letter.
            Cannot end with a hyphen or contain two consecutive hyphens.
            SourceEndpointArn (string) --The Amazon Resource Name (ARN) string that uniquely identifies the endpoint.
            TargetEndpointArn (string) --The Amazon Resource Name (ARN) string that uniquely identifies the endpoint.
            ReplicationInstanceArn (string) --The Amazon Resource Name (ARN) of the replication instance.
            MigrationType (string) --The type of migration.
            TableMappings (string) --Table mappings specified in the task.
            ReplicationTaskSettings (string) --The settings for the replication task.
            Status (string) --The status of the replication task.
            LastFailureMessage (string) --The last error (failure) message generated for the replication instance.
            ReplicationTaskCreationDate (datetime) --The date the replication task was created.
            ReplicationTaskStartDate (datetime) --The date the replication task is scheduled to start.
            ReplicationTaskArn (string) --The Amazon Resource Name (ARN) of the replication task.
            ReplicationTaskStats (dict) --The statistics for the task, including elapsed time, tables loaded, and table errors.
            FullLoadProgressPercent (integer) --The percent complete for the full load migration task.
            ElapsedTimeMillis (integer) --The elapsed time of the task, in milliseconds.
            TablesLoaded (integer) --The number of tables loaded for this task.
            TablesLoading (integer) --The number of tables currently loading for this task.
            TablesQueued (integer) --The number of tables queued for this task.
            TablesErrored (integer) --The number of errors that have occurred during this task.
            
            
            
    :type ReplicationTaskArn: string
    """
    pass

def test_connection(ReplicationInstanceArn=None, EndpointArn=None):
    """
    :param ReplicationInstanceArn: [REQUIRED]
            The Amazon Resource Name (ARN) of the replication instance.
            
    :type ReplicationInstanceArn: string
    :param EndpointArn: [REQUIRED]
            The Amazon Resource Name (ARN) string that uniquely identifies the endpoint.
            
    :type EndpointArn: string
    """
    pass




"""
The MIT License (MIT)

Copyright (c) 2016 Gehad Shaat

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


def can_paginate(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            ReturnsTrue if the operation can be paginated,
            False otherwise.
            
    :type operation_name: string
    """
    pass

def cancel_job(JobId=None, APIVersion=None):
    """
    :param JobId: [REQUIRED] A unique identifier which refers to a particular job.
    :type JobId: string
    :param APIVersion: Specifies the version of the client tool.
    :type APIVersion: string
    """
    pass

def create_job(JobType=None, Manifest=None, ManifestAddendum=None, ValidateOnly=None, APIVersion=None):
    """
    :param JobType: [REQUIRED] Specifies whether the job to initiate is an import or export job.
    :type JobType: string
    :param Manifest: [REQUIRED] The UTF-8 encoded text of the manifest file.
    :type Manifest: string
    :param ManifestAddendum: For internal use only.
    :type ManifestAddendum: string
    :param ValidateOnly: [REQUIRED] Validate the manifest and parameter values in the request but do not actually create a job.
    :type ValidateOnly: boolean
    :param APIVersion: Specifies the version of the client tool.
    :type APIVersion: string
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    :param ClientMethod: The client method to presign for
    :type ClientMethod: string
    :param Params: The parameters normally passed to
            ClientMethod.
    :type Params: dict
    :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)
    :type ExpiresIn: int
    :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.
    :type HttpMethod: string
    """
    pass

def get_paginator(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            Raises OperationNotPageableErrorRaised if the operation is not
            pageable. You can use the client.can_paginate method to
            check if an operation is pageable.
            Return typeL{botocore.paginate.Paginator}
            ReturnsA paginator object.
            
    :type operation_name: string
    """
    pass

def get_shipping_label(jobIds=None, name=None, company=None, phoneNumber=None, country=None, stateOrProvince=None, city=None, postalCode=None, street1=None, street2=None, street3=None, APIVersion=None):
    """
    :param jobIds: [REQUIRED]
            (string) --
            
    :type jobIds: list
    :param name: Specifies the name of the person responsible for shipping this package.
    :type name: string
    :param company: Specifies the name of the company that will ship this package.
    :type company: string
    :param phoneNumber: Specifies the phone number of the person responsible for shipping this package.
    :type phoneNumber: string
    :param country: Specifies the name of your country for the return address.
    :type country: string
    :param stateOrProvince: Specifies the name of your state or your province for the return address.
    :type stateOrProvince: string
    :param city: Specifies the name of your city for the return address.
    :type city: string
    :param postalCode: Specifies the postal code for the return address.
    :type postalCode: string
    :param street1: Specifies the first part of the street address for the return address, for example 1234 Main Street.
    :type street1: string
    :param street2: Specifies the optional second part of the street address for the return address, for example Suite 100.
    :type street2: string
    :param street3: Specifies the optional third part of the street address for the return address, for example c/o Jane Doe.
    :type street3: string
    :param APIVersion: Specifies the version of the client tool.
    :type APIVersion: string
    """
    pass

def get_status(JobId=None, APIVersion=None):
    """
    :param JobId: [REQUIRED] A unique identifier which refers to a particular job.
    :type JobId: string
    :param APIVersion: Specifies the version of the client tool.
    :type APIVersion: string
    """
    pass

def get_waiter():
    """
    """
    pass

def list_jobs(MaxJobs=None, Marker=None, APIVersion=None):
    """
    :param MaxJobs: Sets the maximum number of jobs returned in the response. If there are additional jobs that were not returned because MaxJobs was exceeded, the response contains IsTruncatedtrue/IsTruncated. To return the additional jobs, see Marker.
    :type MaxJobs: integer
    :param Marker: Specifies the JOBID to start after when listing the jobs created with your account. AWS Import/Export lists your jobs in reverse chronological order. See MaxJobs.
    :type Marker: string
    :param APIVersion: Specifies the version of the client tool.
    :type APIVersion: string
    """
    pass

def update_job(JobId=None, Manifest=None, JobType=None, ValidateOnly=None, APIVersion=None):
    """
    :param JobId: [REQUIRED] A unique identifier which refers to a particular job.
    :type JobId: string
    :param Manifest: [REQUIRED] The UTF-8 encoded text of the manifest file.
    :type Manifest: string
    :param JobType: [REQUIRED] Specifies whether the job to initiate is an import or export job.
    :type JobType: string
    :param ValidateOnly: [REQUIRED] Validate the manifest and parameter values in the request but do not actually create a job.
    :type ValidateOnly: boolean
    :param APIVersion: Specifies the version of the client tool.
    :type APIVersion: string
    """
    pass




"""
The MIT License (MIT)

Copyright (c) 2016 Gehad Shaat

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


def can_paginate(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            ReturnsTrue if the operation can be paginated,
            False otherwise.
            
    :type operation_name: string
    """
    pass

def create_tags(configurationIds=None, tags=None):
    """
    :param configurationIds: [REQUIRED]
            A list of configuration items that you want to tag.
            (string) --
            
    :type configurationIds: list
    :param tags: [REQUIRED]
            Tags that you want to associate with one or more configuration items. Specify the tags that you want to create in a key -value format. For example:
            {'key': 'serverType', 'value': 'webServer'}
            (dict) --Metadata that help you categorize IT assets.
            key (string) -- [REQUIRED]A type of tag to filter on.
            value (string) -- [REQUIRED]A value for a tag key to filter on.
            
            
    :type tags: list
    """
    pass

def delete_tags(configurationIds=None, tags=None):
    """
    :param configurationIds: [REQUIRED]
            A list of configuration items with tags that you want to delete.
            (string) --
            
    :type configurationIds: list
    :param tags: Tags that you want to delete from one or more configuration items. Specify the tags that you want to delete in a key -value format. For example:
            {'key': 'serverType', 'value': 'webServer'}
            (dict) --Metadata that help you categorize IT assets.
            key (string) -- [REQUIRED]A type of tag to filter on.
            value (string) -- [REQUIRED]A value for a tag key to filter on.
            
            
    :type tags: list
    """
    pass

def describe_agents(agentIds=None, maxResults=None, nextToken=None):
    """
    :param agentIds: The agent IDs for which you want information. If you specify no IDs, the system returns information about all agents associated with your AWS user account.
            (string) --
            
    :type agentIds: list
    :param maxResults: The total number of agents to return. The maximum value is 100.
    :type maxResults: integer
    :param nextToken: A token to start the list. Use this token to get the next set of results.
    :type nextToken: string
    """
    pass

def describe_configurations(configurationIds=None):
    """
    :param configurationIds: [REQUIRED]
            One or more configuration IDs.
            (string) --
            Return typedict
            ReturnsResponse Syntax{
              'configurations': [
                {
                  'string': 'string'
                },
              ]
            }
            Response Structure
            (dict) --
            configurations (list) --A key in the response map. The value is an array of data.
            (dict) --
            (string) --
            (string) --
            
            
            
    :type configurationIds: list
    """
    pass

def describe_export_configurations(exportIds=None, maxResults=None, nextToken=None):
    """
    :param exportIds: A unique identifier that you can use to query the export status.
            (string) --
            
    :type exportIds: list
    :param maxResults: The maximum number of results that you want to display as a part of the query.
    :type maxResults: integer
    :param nextToken: A token to get the next set of results. For example, if you specified 100 IDs for DescribeConfigurationsRequest$configurationIds but set DescribeExportConfigurationsRequest$maxResults to 10, you will get results in a set of 10. Use the token in the query to get the next set of 10.
    :type nextToken: string
    """
    pass

def describe_tags(filters=None, maxResults=None, nextToken=None):
    """
    :param filters: You can filter the list using a key -value format. You can separate these items by using logical operators. Allowed filters include tagKey , tagValue , and configurationId .
            (dict) --The name of a tag filter. Valid names are: tagKey , tagValue , configurationId .
            name (string) -- [REQUIRED]A name of a tag filter.
            values (list) -- [REQUIRED]Values of a tag filter.
            (string) --
            
            
    :type filters: list
    :param maxResults: The total number of items to return. The maximum value is 100.
    :type maxResults: integer
    :param nextToken: A token to start the list. Use this token to get the next set of results.
    :type nextToken: string
    """
    pass

def export_configurations():
    """
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    :param ClientMethod: The client method to presign for
    :type ClientMethod: string
    :param Params: The parameters normally passed to
            ClientMethod.
    :type Params: dict
    :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)
    :type ExpiresIn: int
    :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.
    :type HttpMethod: string
    """
    pass

def get_paginator(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            Raises OperationNotPageableErrorRaised if the operation is not
            pageable. You can use the client.can_paginate method to
            check if an operation is pageable.
            Return typeL{botocore.paginate.Paginator}
            ReturnsA paginator object.
            
    :type operation_name: string
    """
    pass

def get_waiter():
    """
    """
    pass

def list_configurations(configurationType=None, filters=None, maxResults=None, nextToken=None):
    """
    :param configurationType: [REQUIRED]
            A valid configuration identified by the Discovery Service.
            
    :type configurationType: string
    :param filters: You can filter the list using a key -value format. For example:
            {'key': 'serverType', 'value': 'webServer'}
            You can separate these items by using logical operators.
            (dict) --A filter that can use conditional operators.
            name (string) -- [REQUIRED]The name of the filter. The following filter names are allowed for SERVER configuration items.
            Server
            server.hostName
            server.osName
            server.osVersion
            server.configurationid
            server.agentid
            The name of the filter. The following filter names are allowed for PROCESS configuration items.
            Process
            process.configurationid
            process.name
            process.commandLine
            server.configurationid
            server.hostName
            server.osName
            server.osVersion
            server.agentId
            The name of the filter. The following filter names are allowed for CONNECTION configuration items.
            Connection
            connection.sourceIp
            connection.destinationIp
            connection.destinationPort
            sourceProcess.configurationId
            sourceProcess.name
            sourceProcess.commandLine
            destinationProcess.configurationId
            destinationProcess.name
            destinationProcess.commandLine
            sourceServer.configurationId
            sourceServer.hostName
            sourceServer.osName
            sourceServer.osVersion
            sourceServer.agentId
            destinationServer.configurationId
            destinationServer.hostName
            destinationServer.osName
            destinationServer.osVersion
            destinationServer.agentId
            values (list) -- [REQUIRED]A string value that you want to filter on. For example, if you choose the destinationServer.osVersion filter name, you could specify Ubuntu for the value.
            (string) --
            condition (string) -- [REQUIRED]A conditional operator. The following operators are valid: EQUALS, NOT_EQUALS, CONTAINS, NOT_CONTAINS. If you specify multiple filters, the system utilizes all filters as though concatenated by AND . If you specify multiple values for a particular filter, the system differentiates the values using OR . Calling either DescribeConfigurations or ListConfigurations returns attributes of matching configuration items.
            
            
    :type filters: list
    :param maxResults: The total number of items to return. The maximum value is 100.
    :type maxResults: integer
    :param nextToken: A token to start the list. Use this token to get the next set of results.
    :type nextToken: string
    """
    pass

def start_data_collection_by_agent_ids(agentIds=None):
    """
    :param agentIds: [REQUIRED]
            The IDs of the agents that you want to start collecting data. If you send a request to an AWS agent ID that you do not have permission to contact, according to your AWS account, the service does not throw an exception. Instead, it returns the error in the Description field. If you send a request to multiple agents and you do not have permission to contact some of those agents, the system does not throw an exception. Instead, the system shows Failed in the Description field.
            (string) --
            Return typedict
            ReturnsResponse Syntax{
              'agentsConfigurationStatus': [
                {
                  'agentId': 'string',
                  'operationSucceeded': True|False,
                  'description': 'string'
                },
              ]
            }
            Response Structure
            (dict) --
            agentsConfigurationStatus (list) --Information about agents that were instructed to start collecting data. Information includes the agent ID, a description of the operation performed, and whether or not the agent configuration was updated.
            (dict) --Information about agents that were instructed to start collecting data. Information includes the agent ID, a description of the operation, and whether or not the agent configuration was updated.
            agentId (string) --The agent ID.
            operationSucceeded (boolean) --Information about the status of the StartDataCollection and StopDataCollection operations. The system has recorded the data collection operation. The agent receives this command the next time it polls for a new command.
            description (string) --A description of the operation performed.
            
            
            
    :type agentIds: list
    """
    pass

def stop_data_collection_by_agent_ids(agentIds=None):
    """
    :param agentIds: [REQUIRED]
            The IDs of the agents that you want to stop collecting data.
            (string) --
            Return typedict
            ReturnsResponse Syntax{
              'agentsConfigurationStatus': [
                {
                  'agentId': 'string',
                  'operationSucceeded': True|False,
                  'description': 'string'
                },
              ]
            }
            Response Structure
            (dict) --
            agentsConfigurationStatus (list) --Information about agents that were instructed to stop collecting data. Information includes the agent ID, a description of the operation performed, and whether or not the agent configuration was updated.
            (dict) --Information about agents that were instructed to start collecting data. Information includes the agent ID, a description of the operation, and whether or not the agent configuration was updated.
            agentId (string) --The agent ID.
            operationSucceeded (boolean) --Information about the status of the StartDataCollection and StopDataCollection operations. The system has recorded the data collection operation. The agent receives this command the next time it polls for a new command.
            description (string) --A description of the operation performed.
            
            
            
    :type agentIds: list
    """
    pass

